@@ -23,11 +23,11 @@ our $utf8 = "\x{100}\x{df}";
 #'ฉันกินกระจกได้ แต่มันไม่ทำให้ฉันเจ็บ';
 utf8::encode( my $utf8_bytes = $utf8 );
 my $utf8_length = bytes::length($utf8_bytes);
-our $UTF8 = 'U' . $utf8_length . ':' . $utf8_bytes;
+our $UTF8 = 'U' . $utf8_length . ':' . $utf8_bytes . ',';
 
 our $bytes = pack( 's<', 255 );
 my $bytes_length = bytes::length($bytes);
-our $BYTES = 'B' . $bytes_length . ':' . $bytes;
+our $BYTES = 'B' . $bytes_length . ':' . $bytes . ',';
 
 our $data1 = {
     bools   => [ $Bifcode::FALSE, $Bifcode::TRUE, ],
@@ -39,12 +39,12 @@ our $data1 = {
 };
 
 our $DATA1 = '{'
-  . ( 'U5:bools' . '[01]' )
-  . ( 'U5:bytes' . $BYTES )
-  . ( 'U5:float' . 'F-1.25e-9,' )
-  . ( 'U7:integer' . 'I25,' )
-  . ( 'U5:undef' . '~' )
-  . ( 'U4:utf8' . $UTF8 ) . '}';
+  . ( 'U5:bools,' . '[01]' )
+  . ( 'U5:bytes,' . $BYTES )
+  . ( 'U5:float,' . 'F-1.25e-9,' )
+  . ( 'U7:integer,' . 'I25,' )
+  . ( 'U5:undef,' . '~' )
+  . ( 'U4:utf8,' . $UTF8 ) . '}';
 
 our $data2 = {
     bools   => [ $Bifcode::FALSE, $Bifcode::TRUE, ],
@@ -56,12 +56,12 @@ our $data2 = {
 };
 
 our $DATA2 = '{'
-  . ( 'U5:bools' . '[01]' )
-  . ( 'U5:bytes' . $BYTES )
-  . ( 'U5:float' . 'F1.25e-9,' )
-  . ( 'U7:integer' . 'I24,' )
-  . ( 'U5:undef' . '~' )
-  . ( 'U4:utf8' . $UTF8 ) . '}';
+  . ( 'U5:bools,' . '[01]' )
+  . ( 'U5:bytes,' . $BYTES )
+  . ( 'U5:float,' . 'F1.25e-9,' )
+  . ( 'U7:integer,' . 'I24,' )
+  . ( 'U5:undef,' . '~' )
+  . ( 'U4:utf8,' . $UTF8 ) . '}';
 
 sub enc_ok {
     croak 'usage: enc_ok($1,$2)'
@@ -89,9 +89,10 @@ sub enc_error_ok {
 sub un {
     my ($frozen) = @_;
     local $, = ', ';
+    my $frozen_str = $frozen // '*undef*';
     return 'ARRAY' eq ref $frozen
-      ? ( "decode [@$frozen]", decode_bifcode @$frozen )
-      : ( "decode '$frozen'", decode_bifcode $frozen );
+      ? ( "decode [@$frozen_str]", decode_bifcode @$frozen )
+      : ( "decode '$frozen_str'", decode_bifcode $frozen );
 }
 
 sub decod_ok {
